const createExpressDriver = ({ express, port = 3000 }) => {
  var server = express()

  const onCreate = (endpoint, createFn) => {
    server.post(`/${endpoint}`, function(req, res) {
      const data = req.body
      createFn(data, result => res.send(result))
    })
  }

  const onRead = (endpoint, readFn) => {
    server.get(`/${endpoint}/:id`, function(req, res) {
      readFn(req.params.id, result => res.send(result))
    })
  }

  const onList = (endpoint, readFn) => {
    server.get(`/${endpoint}`, function(req, res) {
      readFn(result => res.send(result))
    })
  }

  const onUpdate = (endpoint, updateFn) => {
    server.patch(`/${endpoint}/:id`, function(req, res) {
      updateFn(req.params.id, result => res.send(result))
    })
  }

  const onDelete = (endpoint, deleteFn) => {
    server.delete(`/${endpoint}/:id`, function(req, res) {
      deleteFn(req.params.id, result => res.send(result))
    })
  }

  server.listen(port)

  return {
    onCreate,
    onRead,
    onList,
    onUpdate,
    onDelete,
  }
}

module.exports = createExpressDriver
